@@ -33,19 +33,20 @@ Classes
 
 """
 import argparse
+import os
 import sys
 import typing as t
 
 from torxtools import xdgtools
+from torxtools.argtools import is_not_dir
 from torxtools.cfgtools import which
-from torxtools.pathtools import expandpath
+from torxtools.pathtools import cachedir, expandpath
 from yaml import safe_load
 
 from ._utils import deepmerge
 from .defaults import CFGFILE_SEARCH_PATHS, make_config
 from .flask import FlaskHelper
 from .gunicorn import GunicornHelper
-from torxtools.argtools import is_not_dir
 
 
 def _read(cfgfile: str) -> t.Dict[str, t.Any]:
@@ -80,6 +81,7 @@ class ArgParse:
         default_cfg: t.Dict[str, t.Any] = None,
         description="Flasket server",
         key: str = "SETTINGS",
+        appname: str = None,
     ):
         """
         Parameters
@@ -117,6 +119,10 @@ class ArgParse:
         key: str
 
             Keyname where to save settings, defaults to app.config["SETTINGS"]
+
+        appname: str
+
+            Application name. Used to figure out cachepath. Otherwise, defaults to sys.argv[0]
         """
         if app is not None:
             self.init_app(
@@ -128,6 +134,7 @@ class ArgParse:
                 default_cfg=default_cfg,
                 description=description,
                 key=key,
+                appname=appname,
             )
 
     def init_app(
@@ -140,6 +147,7 @@ class ArgParse:
         default_cfg: t.Dict[str, t.Any] = None,
         description="Flask server",
         key: str = "SETTINGS",
+        appname: str = None,
     ):
         # Sets environment variables for XDG paths
         xdgtools.setenv()
@@ -168,6 +176,8 @@ class ArgParse:
         # Parse arguments if they exist
         if argv is None:
             argv = sys.argv[1:]
+            if appname is None:
+                appname = os.path.basename(sys.argv[0])
 
         arguments = self._parse_arguments(
             argv=argv,
@@ -196,7 +206,11 @@ class ArgParse:
         cfg = deepmerge(cfg, arguments)
         cfg = helper.force_cfg(cfg)
 
+        path = cfg.get("server", {}).get("cachedir", {})
         app.config[key] = cfg
+
+        app.cachedir = cachedir(appname, path)
+
         return app
 
     @staticmethod
